==> kubernetes-model-1.0.29-sources.jar: annotations/io/fabric8/kubernetes/api/model/ContainerStateRunningFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;

public class ContainerStateRunningFluentImpl<T extends ContainerStateRunningFluent<T>> extends BaseFluent<T> implements ContainerStateRunningFluent<T>{

     String startedAt;     Map<String, Object> additionalProperties = new HashMap();

    public String getStartedAt(){
    return this.startedAt;
    }
    public T withStartedAt( String startedAt){
    this.startedAt=startedAt; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
ContainerStateRunningFluentImpl that = (ContainerStateRunningFluentImpl) o;
if (startedAt != null ? !startedAt.equals(that.startedAt) :that.startedAt != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}

==> kubernetes-model-1.0.51-sources.jar: annotations/io/fabric8/kubernetes/api/model/ContainerStateRunningFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class ContainerStateRunningFluentImpl<T extends ContainerStateRunningFluent<T>> extends BaseFluent<T> implements ContainerStateRunningFluent<T>{

     String startedAt;     Map<String, Object> additionalProperties = new HashMap();
public ContainerStateRunningFluentImpl(){
    
}
public ContainerStateRunningFluentImpl( ContainerStateRunning instance ){
    this.withStartedAt(instance.getStartedAt()); 
}

    public String getStartedAt(){
    return this.startedAt;
    }
    public T withStartedAt( String startedAt){
    this.startedAt=startedAt; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
ContainerStateRunningFluentImpl that = (ContainerStateRunningFluentImpl) o;
if (startedAt != null ? !startedAt.equals(that.startedAt) :that.startedAt != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}
